@@ -1,8 +1,14 @@
 #ifndef MEASLESQUARANTINE_HPP
 #define MEASLESQUARANTINE_HPP
 
-#if __cplusplus >= 202302L
-    // C++23 or later
+#if defined(__clang__)
+    // Clang
+    #define GET_MODEL(model, output) \
+        ModelMeaslesSchool<TSeq> * output = \
+            dynamic_cast<ModelMeaslesSchool<TSeq> *>(model); \
+        __builtin_assume(output != nullptr);
+#elif defined(__GNUC__) && __GNUC__ >= 13
+    // GCC 13 or later
     #define GET_MODEL(model, output) \
         ModelMeaslesSchool<TSeq> * output = \
             dynamic_cast<ModelMeaslesSchool<TSeq> *>(model); \
@@ -44,9 +50,14 @@
  * detected. The agent is then isolated and all agents who are unvaccinated are
  * quarantined. Isolated agents then may be moved out of the isolation in
  * isolation_period days.
+ * 
+ * ![Model Diagram](../assets/img/measlesschool.png)
+ * 
+ * 
+ * @ingroup disease_specific
  */
 template<typename TSeq = EPI_DEFAULT_TSEQ>
-class ModelMeaslesSchool: public Model<TSeq> {
+class ModelMeaslesSchool: public epiworld::Model<TSeq> {
 
 private:
 
@@ -76,6 +87,11 @@ private:
 
 public:
 
+    /**
+     * @name Model States
+     * @brief The different states of the model.
+     */
+    ///@{
     static constexpr epiworld_fast_uint SUSCEPTIBLE             = 0u;
     static constexpr epiworld_fast_uint EXPOSED                 = 1u;
     static constexpr epiworld_fast_uint PRODROMAL               = 2u;
@@ -89,6 +105,7 @@ public:
     static constexpr epiworld_fast_uint QUARANTINED_RECOVERED   = 10u;
     static constexpr epiworld_fast_uint HOSPITALIZED            = 11u;
     static constexpr epiworld_fast_uint RECOVERED               = 12u;
+    ///@}
     
     // Default constructor
     ModelMeaslesSchool() {};
@@ -309,15 +326,25 @@ inline void ModelMeaslesSchool<TSeq>::update_infectious() {
         if (s == PRODROMAL)
             this->infectious.push_back(&agent);
 
-        if (s < RASH)
+        if ((s < RASH) || (s == RECOVERED))
             ++n_available;
 
     }
 
     // Assumes fixed contact rate throughout the simulation
-    double p_contact = this->par("Contact rate")/
-        static_cast< epiworld_double >(n_available);
+    // but corrects for the number of available agents.
+    double p_contact = 0.0;
+    if (n_available > 0)
+    {
+        p_contact = this->par("Contact rate")/
+            static_cast< epiworld_double >(n_available);
+    }
 
+    // Notice this is for sampling with replacement
+    // from the list of infected individuals.
+    // This is a partial drawing which, complemented with
+    // drawing from the non-infected individuals, yields
+    // a Binomial(n, contact_rate/n) number of contacts.
     this->set_rand_binom(
         static_cast<int>(this->infectious.size()),
         p_contact > 1.0 ? 1.0 : p_contact
@@ -498,6 +525,7 @@ LOCAL_UPDATE_FUN(m_update_rash) {
     {
         // If hospitalized, then the agent is removed from the system
         // effectively
+        model->record_hospitalization(*p);
         p->change_state(
             m,
             detected ?
@@ -557,6 +585,7 @@ LOCAL_UPDATE_FUN(m_update_isolated) {
     // If hospitalized, then the agent is removed from the system
     else if (which == 1u)
     {
+        model->record_hospitalization(*p);
         p->change_state(
             m,
             // HOSPITALIZED
